/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: inherit_p.h 1393 2007-11-22 18:26:05Z martin $
    begin       : Sun Dec 05 2003
    copyright   : (C) 2003 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GWENHYWFAR_INHERIT_P_H
#define GWENHYWFAR_INHERIT_P_H


#include <gwenhywfar/inherit.h>
#include <gwenhywfar/misc.h>
#include <gwenhywfar/gwenhywfarapi.h>


struct GWEN_INHERITDATA {
  GWEN_LIST_ELEMENT(GWEN_INHERITDATA)
  /* No trailing semicolon here because this is a macro call */

  uint32_t id;
  void *data;
  void *baseData;
  GWEN_INHERIT_FREEDATAFN freeDataFn;
  char *typeName;
};



#endif /* GWENHYWFAR_INHERIT_P_H */



